@@ -35,7 +35,10 @@ def safe_set_value_to_widget(widget, value):
     # do not set when value equals current value
     # will not generate events when changed
     
-    if isinstance(widget, (QSpinBox, QDoubleSpinBox)):
+    if isinstance(widget, QSpinBox):
+        if widget.value() != safe_to_int(value):
+            widget.setValue(safe_to_int(value))
+    elif isinstance(widget, QDoubleSpinBox):
         if widget.value() != safe_to_float(value):
             widget.setValue(safe_to_float(value))
     elif isinstance(widget, (QLineEdit, QLabel)):
